@@ -1,6 +1,17 @@
 package App::Ack::Resources;
 
+=head1 NAME
+
+App::Ack::Resources
+
+=head1 SYNOPSIS
+
+A factory object for creating a stream of L<App::Ack::Resource> objects.
+
+=cut
+
 use App::Ack;
+use App::Ack::Resource;
 
 use File::Next 1.16;
 use Errno qw(EACCES);
@@ -28,11 +39,6 @@ sub _generate_error_handler {
     }
 }
 
-=head1 SYNOPSIS
-
-This is the base class for App::Ack::Resources, an iterator factory
-for App::Ack::Resource objects.
-
 =head1 METHODS
 
 =head2 from_argv( \%opt, \@starting_points )
@@ -117,9 +123,11 @@ sub from_stdin {
 sub next {
     my $self = shift;
 
-    my $file = $self->{iter}->() or return;
+    my $file = $self->{iter}->();
 
-    return App::Ack::Resource::Basic->new( $file );
+    return unless defined($file);
+
+    return App::Ack::Resource->new( $file );
 }
 
 1;
