@@ -1,13 +1,66 @@
+package Util;
+
+use parent 'Exporter';
+
+use warnings;
+use strict;
 
 use Carp ();
-use File::Next ();
-use App::Ack ();
 use Cwd ();
+use File::Next ();
 use File::Spec ();
 use File::Temp ();
 use Term::ANSIColor ();
 use Test::More;
 
+our @EXPORT = qw(
+    prep_environment
+    touch_ackrc
+
+    has_io_pty
+    is_windows
+    is_cygwin
+
+    is_empty_array
+    is_nonempty_array
+
+    first_line_like
+    build_ack_invocation
+
+    read_file
+    write_file
+    append_file
+
+    reslash
+    reslash_all
+    windows_slashify
+
+    run_cmd
+    run_ack
+    run_ack_with_stderr
+    run_ack_interactive
+    pipe_into_ack
+    pipe_into_ack_with_stderr
+
+    lists_match
+    sets_match
+    ack_lists_match
+    ack_sets_match
+
+    untaint
+
+    line_split
+    colorize
+    caret_X
+    get_rc
+    getcwd_clean
+
+    safe_chdir
+    safe_mkdir
+
+    get_options
+);
+
 my $orig_wd;
 my @temp_files; # We store temp files here to make sure they're properly reclaimed at interpreter shutdown.
 
@@ -171,10 +224,12 @@ sub _write_file {
     return;
 }
 
-sub break_up_lines {
-    my $str = shift;
+sub line_split {
+    return split( /\n/, $_[0] );
+}
 
-    return split( /\n/, $str );
+sub reslash {
+    return File::Next::reslash( shift );
 }
 
 sub reslash_all {
@@ -328,7 +383,7 @@ sub run_cmd {
 
     my ($sig,$core,$rc) = (($? & 127),  ($? & 128) , ($? >> 8));
     $ack_return_code = $rc;
-    ## XXX what do do with $core or $sig?
+    ## XXX what to do with $core or $sig?
 
     chomp @stdout;
     chomp @stderr;
@@ -407,6 +462,7 @@ sub lists_match {
     return subtest "lists_match( $msg )" => sub {
         plan tests => 1;
 
+        my $ok;
         my $rc = eval 'use Test::Differences; 1;';
         if ( $rc ) {
             $ok = eq_or_diff( [@actual], [@expected], $msg );
@@ -481,7 +537,7 @@ sub record_option_coverage {
     my ( @command_line ) = @_;
 
     return unless $ENV{ACK_OPTION_COVERAGE};
-    return if $ENV{ACK_STANDALONE}; # We don't need to record the second time around.
+    return if $ENV{ACK_TEST_STANDALONE}; # We don't need to record the second time around.
 
     my $record_options = File::Spec->catfile($orig_wd, 'record-options');
 
@@ -626,12 +682,12 @@ BEGIN {
 
         *run_ack_interactive = sub {
             local $Test::Builder::Level = $Test::Builder::Level + 1;
-            Test::More::fail(<<'END_FAIL');
+            Test::More::fail(<<'HERE');
 Your system doesn't seem to have IO::Pty, and the developers
 forgot to check in this test file.  Please file a bug report
-at https://github.com/petdance/ack2/issues with the name of
+at https://github.com/beyondgrep/ack2/issues with the name of
 the file that generated this failure.
-END_FAIL
+HERE
         };
     }
 }
@@ -798,4 +854,28 @@ sub windows_slashify {
     return $str;
 }
 
+sub touch_ackrc {
+    my $filename = shift or die;
+    write_file( $filename, () );
+
+    return;
+}
+
+
+sub safe_chdir {
+    my $dir = shift;
+
+    CORE::chdir( $dir ) or die "Can't chdir to $dir: $!";
+
+    return;
+}
+
+
+sub safe_mkdir {
+    my $dir = shift;
+
+    CORE::mkdir( $dir ) or die "Can't mkdir $dir: $!";
+
+    return;
+}
 1;
